@@ -17,6 +17,8 @@
 
 #pragma once
 
+#include <lomiri/SymbolExport.h>
+
 #include <string>
 
 namespace lomiri
@@ -25,7 +27,7 @@ namespace lomiri
 namespace util
 {
 
-    std::string prepend_snap_path(const std::string& path);
+    LOMIRI_API std::string prepend_snap_path(const std::string& path);
 
 } // namespace util
 
